qec\_lego\_bench.cli package
============================

Submodules
----------

qec\_lego\_bench.cli.codes module
---------------------------------

.. automodule:: qec_lego_bench.cli.codes
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.cli.decoders module
------------------------------------

.. automodule:: qec_lego_bench.cli.decoders
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.cli.logical\_error\_rate module
------------------------------------------------

.. automodule:: qec_lego_bench.cli.logical_error_rate
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.cli.noises module
----------------------------------

.. automodule:: qec_lego_bench.cli.noises
   :members:
   :undoc-members:
   :show-inheritance:

qec\_lego\_bench.cli.util module
--------------------------------

.. automodule:: qec_lego_bench.cli.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: qec_lego_bench.cli
   :members:
   :undoc-members:
   :show-inheritance:
